@@ -1,4 +1,4 @@
-# PiTiVi , Non-linear video editor
+# Pitivi video editor
 #
 #       pitivi/pitivi.py
 #
@@ -24,43 +24,46 @@
 """
 Main application
 """
-import gobject
-import gtk
-from optparse import OptionParser
 import os
 import sys
-import urllib
-
-from pitivi.pitivigstutils import patch_gst_python
-patch_gst_python()
+from gi.repository import GES
+from gi.repository import Gio
+from gi.repository import GLib
+from gi.repository import Gtk
 
 from gettext import gettext as _
+from optparse import OptionParser
 
 import pitivi.instance as instance
 
-from pitivi.check import initial_checks
 from pitivi.effects import EffectsHandler
-from pitivi.configure import APPNAME
+from pitivi.configure import APPNAME, pitivi_version, RELEASES_URL
 from pitivi.settings import GlobalSettings
-from pitivi.threads import ThreadMaster
-from pitivi.signalinterface import Signallable
-from pitivi.log.loggable import Loggable
-from pitivi.log import log
-from pitivi.ui.mainwindow import PitiviMainWindow
-from pitivi.projectmanager import ProjectManager, ProjectLogObserver
-from pitivi.undo import UndoableActionLog, DebugActionLogObserver
-from pitivi.timeline.timeline_undo import TimelineLogObserver
-from pitivi.sourcelist_undo import SourceListLogObserver
-from pitivi.ui.viewer import PitiviViewer
-from pitivi.actioner import Renderer, Previewer
-from pitivi.ui.startupwizard import StartUpWizard
+from pitivi.utils.threads import ThreadMaster
+from pitivi.mainwindow import PitiviMainWindow
+from pitivi.project import ProjectManager, ProjectLogObserver
+from pitivi.undo.undo import UndoableActionLog, DebugActionLogObserver
+from pitivi.dialogs.startupwizard import StartUpWizard
 
-# FIXME : Speedup loading time
-# Currently we load everything in one go
-# It would be better if a minimalistic UI could start up ASAP, without loading
-# anything gst-related or that could slow down startup.
-# AND THEN load up the required parts.
-# This will result in a much better end-user experience
+from pitivi.utils.misc import quote_uri
+from pitivi.utils.signal import Signallable
+from pitivi.utils.system import getSystem
+from pitivi.utils.loggable import Loggable
+import pitivi.utils.loggable as log
+#FIXME GES port disabled it
+#from pitivi.undo.timeline import TimelineLogObserver
+
+
+"""
+Hierarchy of the whole thing:
+
+Pitivi
+    InteractivePitivi
+    GuiPitivi
+        ProjectCreatorGuiPitivi
+        ProjectLoaderGuiPitivi
+        StartupWizardGuiPitivi
+"""
 
 
 class Pitivi(Loggable, Signallable):
@@ -97,6 +100,7 @@ class Pitivi(Loggable, Signallable):
         "closing-project": ["project"],
         "project-closed": ["project"],
         "missing-uri": ["formatter", "uri"],
+        "version-info-received": ["versions"],
         "shutdown": None}
 
     def __init__(self):
@@ -107,18 +111,22 @@ class Pitivi(Loggable, Signallable):
 
         # init logging as early as possible so we can log startup code
         enable_color = os.environ.get('PITIVI_DEBUG_NO_COLOR', '0') in ('', '0')
-        log.init('PITIVI_DEBUG', enable_color)
+        # Let's show a human-readable pitivi debug output by default, and only
+        # show a crazy unreadable mess when surrounded by gst debug statements.
+        enable_crack_output = "GST_DEBUG" in os.environ
+        log.init('PITIVI_DEBUG', enable_color, enable_crack_output)
 
         self.info('starting up')
 
         # store ourself in the instance global
-        if instance.PiTiVi:
-            raise RuntimeWarning(
-                _("There is already a %s instance, please inform the developers by filing a bug at http://bugzilla.gnome.org/enter_bug.cgi?product=pitivi")
+        if instance.Pitivi:
+            raise RuntimeWarning(_("There is already a %s instance, please inform "
+                "the developers by filing a bug at "
+                "http://bugzilla.gnome.org/enter_bug.cgi?product=pitivi")
                 % APPNAME)
-        instance.PiTiVi = self
+        instance.Pitivi = self
 
-        self.current = None
+        self.current_project = None
 
         # get settings
         self.settings = GlobalSettings()
@@ -126,67 +134,65 @@ class Pitivi(Loggable, Signallable):
         #self.screencast = False
 
         self.effects = EffectsHandler()
+        self.system = getSystem()
 
-        self.projectManager = ProjectManager(self.effects)
+        self.projectManager = ProjectManager(self)
         self._connectToProjectManager(self.projectManager)
 
         self.action_log = UndoableActionLog()
         self.debug_action_log_observer = DebugActionLogObserver()
         self.debug_action_log_observer.startObserving(self.action_log)
-        self.timelineLogObserver = TimelineLogObserver(self.action_log)
+        # TODO reimplement the observing after GES port
+        #self.timelineLogObserver = TimelineLogObserver(self.action_log)
         self.projectLogObserver = ProjectLogObserver(self.action_log)
-        self.sourcelist_log_observer = SourceListLogObserver(self.action_log)
+
+        self.version_information = {}
+        self._checkVersion()
 
     def shutdown(self):
         """
-        Close PiTiVi.
+        Close Pitivi.
 
-        @return: C{True} if PiTiVi was successfully closed, else C{False}.
+        @return: C{True} if Pitivi was successfully closed, else C{False}.
         @rtype: C{bool}
         """
         self.debug("shutting down")
         # we refuse to close if we're running a user interface and the user
         # doesn't want us to close the current project.
-        if self.current and not self.projectManager.closeRunningProject():
+        if self.current_project and not self.projectManager.closeRunningProject():
             self.warning("Not closing since running project doesn't want to close")
             return False
         self.threads.stopAllThreads()
         self.settings.storeSettings()
-        self.current = None
-        instance.PiTiVi = None
+        self.current_project = None
+        instance.Pitivi = None
         self.emit("shutdown")
         return True
 
     def _connectToProjectManager(self, projectManager):
-        projectManager.connect("new-project-loading",
-                self._projectManagerNewProjectLoading)
-        projectManager.connect("new-project-created",
-                self._projectManagerNewProjectCreated)
-        projectManager.connect("new-project-loaded",
-                self._projectManagerNewProjectLoaded)
-        projectManager.connect("new-project-failed",
-                self._projectManagerNewProjectFailed)
-        projectManager.connect("closing-project",
-                self._projectManagerClosingProject)
-        projectManager.connect("project-closed",
-                self._projectManagerProjectClosed)
+        pm = projectManager
+        pm.connect("new-project-loading", self._projectManagerNewProjectLoading)
+        pm.connect("new-project-created", self._projectManagerNewProjectCreated)
+        pm.connect("new-project-loaded", self._projectManagerNewProjectLoaded)
+        pm.connect("new-project-failed", self._projectManagerNewProjectFailed)
+        pm.connect("closing-project", self._projectManagerClosingProject)
+        pm.connect("project-closed", self._projectManagerProjectClosed)
 
     def _projectManagerNewProjectLoading(self, projectManager, uri):
         self.emit("new-project-loading", uri)
 
     def _projectManagerNewProjectCreated(self, projectManager, project):
-        self.current = project
+        self.current_project = project
         self.emit("new-project-created", project)
 
     def _newProjectLoaded(self, project):
         pass
 
-    def _projectManagerNewProjectLoaded(self, projectManager, project):
-        self.current = project
+    def _projectManagerNewProjectLoaded(self, projectManager, project, unused_fully_loaded):
+        self.current_project = project
         self.action_log.clean()
-        self.timelineLogObserver.startObserving(project.timeline)
+        #self.timelineLogObserver.startObserving(project.timeline)
         self.projectLogObserver.startObserving(project)
-        self.sourcelist_log_observer.startObserving(project.sources)
         self._newProjectLoaded(project)
         self.emit("new-project-loaded", project)
 
@@ -197,36 +203,57 @@ class Pitivi(Loggable, Signallable):
         return self.emit("closing-project", project)
 
     def _projectManagerProjectClosed(self, projectManager, project):
-        self.timelineLogObserver.stopObserving(project.timeline)
+        #self.timelineLogObserver.stopObserving(project.timeline)
         self.projectLogObserver.stopObserving(project)
-        self.current = None
+        self.current_project = None
         self.emit("project-closed", project)
 
+    def _checkVersion(self):
+        # Check online for release versions information
+        giofile = Gio.File.new_for_uri(RELEASES_URL)
+        self.info("Requesting version information")
+        giofile.load_contents_async(None, self._versionInfoReceivedCb, None)
+
+    def _versionInfoReceivedCb(self, giofile, result, data):
+        try:
+            raw = giofile.load_contents_finish(result)[1]
+            raw = raw.split("\n")
+            # Split line at '=' if the line is not empty or a comment line
+            data = [element.split("=") for element in raw
+                    if element and not element.startswith("#")]
+
+            # search newest version and status
+            status = "UNSUPPORTED"
+            for version, version_status in data:
+                if pitivi_version == version:
+                    status = version_status
+                if version_status.upper() == "CURRENT":
+                    current_version = version
+
+            self.info("Latest software version is %s", current_version)
+            if status is "UNSUPPORTED":
+                self.warning("Using an outdated version of Pitivi (%s)" % pitivi_version)
+
+            self.version_information["current"] = current_version
+            self.version_information["status"] = status
+            self.emit("version-info-received", self.version_information)
+        except Exception, e:
+            self.warning("Version info could not be read: %s" % e)
+
 
 class InteractivePitivi(Pitivi):
     """
-    Base class to launch interactive PiTiVi
+    Base class to launch interactive Pitivi
     """
 
     def __init__(self, debug=False):
         Pitivi.__init__(self)
-        self.mainloop = gobject.MainLoop()
+        self.mainloop = GLib.MainLoop()
         self.actioner = None
         self.gui = None
-
-        # Check the dependencies.
-        missing_deps = initial_checks()
-        if missing_deps:
-            message, detail = missing_deps
-            self._showStartupError(message, detail)
-            sys.exit(2)
-
         if debug:
             sys.excepthook = self._excepthook
 
-    def _showStartupError(self, message, detail):
-        self.error("%s %s" % (message, detail))
-
     def _excepthook(self, exc_type, value, tback):
         import traceback
         import pdb
@@ -247,8 +274,7 @@ class InteractivePitivi(Pitivi):
         raise NotImplementedError()
 
     def _loadProject(self, project_filename):
-        project = "file://%s" % os.path.abspath(project_filename)
-        self.projectManager.loadProject(project)
+        self.projectManager.loadProject(quote_uri(os.path.abspath(project_filename)))
 
     def run(self):
         """Runs the main loop."""
@@ -257,7 +283,10 @@ class InteractivePitivi(Pitivi):
 
 class GuiPitivi(InteractivePitivi):
     """
-    Base class to launch PiTiVi with UI
+    Base class to launch a Pitivi instance with a graphical user interface
+
+    This is called when we start the UI with a project passed as a parameter.
+    It is also called by StartupWizardGuiPitivi.
     """
 
     def __init__(self, debug=False):
@@ -265,9 +294,8 @@ class GuiPitivi(InteractivePitivi):
         self._showGui()
 
     def _showStartupError(self, message, detail):
-        dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR,
-                                   buttons=gtk.BUTTONS_OK)
-        dialog.set_icon_name("pitivi")
+        dialog = Gtk.MessageDialog(type=Gtk.MessageType.ERROR,
+                                   buttons=Gtk.ButtonsType.OK)
         dialog.set_markup("<b>" + message + "</b>")
         dialog.format_secondary_text(detail)
         dialog.run()
@@ -276,8 +304,8 @@ class GuiPitivi(InteractivePitivi):
         self.shutdown()
 
     def _createGui(self):
-        """Returns a gtk.Widget which represents the UI."""
-        raise NotImplementedError()
+        """Returns a Gtk.Widget which represents the UI."""
+        return PitiviMainWindow(self)
 
     def _showGui(self):
         """Creates and shows the UI."""
@@ -292,46 +320,34 @@ class GuiPitivi(InteractivePitivi):
         return False
 
 
-class FullGuiPitivi(GuiPitivi):
+class ProjectCreatorGuiPitivi(GuiPitivi):
     """
-    Creates an instance of PiTiVi with the UI
-
-    This is called when we start the UI with a project passed as a parameter,
-    but not when we start with the welcome dialog.
-    """
-
-    def _createGui(self, **kargs):
-        return PitiviMainWindow(self, **kargs)
-
-
-class ProjectCreatorGuiPitivi(FullGuiPitivi):
-    """
-    Creates an instance of PiTiVi with the UI and loading a list
+    Creates an instance of Pitivi with the UI and loading a list
     of clips, adding them to the timeline or not
     """
 
     def __init__(self, media_filenames, add_to_timeline=False, debug=False):
-        FullGuiPitivi.__init__(self, debug)
+        GuiPitivi.__init__(self, debug)
         # load the passed filenames, optionally adding them to the timeline
         # (useful during development)
-        self.projectManager.newBlankProject()
-        uris = ["file://" + urllib.quote(os.path.abspath(media_filename))
+        self.projectManager.newBlankProject(emission=False)
+        uris = [quote_uri(os.path.abspath(media_filename))
                 for media_filename in media_filenames]
-        self.current.sources.connect("source-added",
-                self._sourceAddedCb, uris, add_to_timeline)
-        self.current.sources.connect("discovery-error",
-                self._discoveryErrorCb, uris)
-        self.current.sources.addUris(uris)
+        lib = self.current_project.medialibrary
+        lib.connect("source-added", self._sourceAddedCb, uris, add_to_timeline)
+        lib.connect("discovery-error", self._discoveryErrorCb, uris)
+        lib.addUris(uris)
 
-    def _sourceAddedCb(self, sourcelist, factory,
-            startup_uris, add_to_timeline):
-        if self._maybePopStartupUri(startup_uris, factory.uri) \
+    def _sourceAddedCb(self, medialibrary, info, startup_uris, add_to_timeline):
+        if self._maybePopStartupUri(startup_uris, info.get_uri()) \
                 and add_to_timeline:
             self.action_log.begin("add clip")
-            self.current.timeline.addSourceFactory(factory)
+            src = GES.UriClip(uri=info.get_uri())
+            src.set_property("priority", 1)
+            self.current_project.timeline.get_layers()[0].add_clip(src)
             self.action_log.commit()
 
-    def _discoveryErrorCb(self, sourcelist, uri, error, debug, startup_uris):
+    def _discoveryErrorCb(self, medialibrary, uri, error, debug, startup_uris):
         self._maybePopStartupUri(startup_uris, uri)
 
     def _maybePopStartupUri(self, startup_uris, uri):
@@ -344,111 +360,54 @@ class ProjectCreatorGuiPitivi(FullGuiPitivi):
             return False
 
         if not startup_uris:
-            self.current.sources.disconnect_by_function(self._sourceAddedCb)
-            self.current.sources.disconnect_by_function(self._discoveryErrorCb)
+            self.current_project.medialibrary.disconnect_by_function(self._sourceAddedCb)
+            self.current_project.medialibrary.disconnect_by_function(self._discoveryErrorCb)
 
         return True
 
 
-class ProjectLoaderGuiPitivi(FullGuiPitivi):
+class ProjectLoaderGuiPitivi(GuiPitivi):
     """
     Creates an instance of the UI and loads @project_filename
     """
 
     def __init__(self, project_filename, debug=False):
-        FullGuiPitivi.__init__(self, debug)
-        self._loadProject(project_filename)
+        GuiPitivi.__init__(self, debug)
+        if not os.path.exists(project_filename):
+            self.error("Project file does not exist: %s" % project_filename)
+            sys.exit(1)
+        else:
+            self._loadProject(project_filename)
 
 
-class StartupWizardGuiPitivi(FullGuiPitivi):
+class StartupWizardGuiPitivi(GuiPitivi):
     """
-    Creates an instance of the PiTiVi UI with the welcome dialog
+    Creates an instance of the Pitivi UI with the welcome dialog
 
     This is not called when a project is passed as a parameter.
     """
 
     def __init__(self, debug=False):
-        FullGuiPitivi.__init__(self, debug)
+        GuiPitivi.__init__(self, debug)
+        self.projectManager.newBlankProject(emission=False)
 
     def _createGui(self):
-        self.wizard = StartUpWizard(self)
         # Prevent the main window to go fullscreen because at least
         # the Metacity window manager will refuse to bring
         # the startup wizard window in front of the main window.
-        return FullGuiPitivi._createGui(self, allow_full_screen=False)
+        return PitiviMainWindow(self, allow_full_screen=False)
 
     def _showGui(self):
-        FullGuiPitivi._showGui(self)
+        GuiPitivi._showGui(self)
+        self.wizard = StartUpWizard(self)
         self.wizard.show()
 
 
-class PreviewGuiPitivi(GuiPitivi):
-    """
-    Creates an instance of PiTiVi which plays the @project_filename
-    in a basic UI.
-    """
-
-    def __init__(self, project_filename, debug=False):
-        GuiPitivi.__init__(self, debug)
-        self._loadProject(project_filename)
-
-    def _createGui(self):
-        self.viewer = PitiviViewer(self)
-        window = gtk.Window()
-        window.connect("delete-event", self._deleteCb)
-        window.add(self.viewer)
-        return window
-
-    def _deleteCb(self, unused_widget, unused_data):
-        self.shutdown()
-
-    def _eosCb(self, unused_obj):
-        self.viewer.seek(0)
-
-    def _newProjectLoaded(self, project):
-        # create previewer and set ui
-        previewer = Previewer(project, ui=self.viewer)
-        self._setActioner(previewer)
-        # hack to make the gtk.HScale seek slider UI behave properly
-        self.viewer._durationChangedCb(None, project.timeline.duration)
-
-
-class RenderingNoGuiPitivi(InteractivePitivi):
-    """
-    Creates an instance of PiTiVi with no UI which aims
-    at rendering the @project_filename project in @output_filename file
-    """
-
-    def __init__(self, project_filename, output_filename, debug=False):
-        InteractivePitivi.__init__(self, debug)
-        self.outfile = "file://%s" % os.path.abspath(output_filename)
-        print _("Loading project...")
-        self._loadProject(project_filename)
-
-    def _eosCb(self, unused_obj):
-        self.shutdown()
-
-    def _newProjectLoaded(self, project):
-        # create renderer and set output file
-        renderer = Renderer(project, outfile=self.outfile)
-        print _("Project loaded.")
-        print _("Rendering...")
-        self._setActioner(renderer)
-
-    def shutdown(self):
-        if Pitivi.shutdown(self):
-            self.mainloop.quit()
-            return True
-        return False
-
-
 def _parse_options(argv):
     parser = OptionParser(
-            usage=_("""
+        usage=_("""
     %prog [PROJECT_FILE]               # Start the video editor.
-    %prog -i [-a] [MEDIA_FILE1 ...]    # Start the editor and create a project.
-    %prog PROJECT_FILE -r OUTPUT_FILE  # Render a project.
-    %prog PROJECT_FILE -p              # Preview a project."""))
+    %prog -i [-a] [MEDIA_FILE1 ...]    # Start the editor and create a project."""))
 
     parser.add_option("-i", "--import", dest="import_sources",
             action="store_true", default=False,
@@ -459,21 +418,9 @@ def _parse_options(argv):
     parser.add_option("-d", "--debug",
             action="store_true", default=False,
             help=_("Run Pitivi in the Python Debugger."))
-    parser.add_option("-r", "--render", dest="render_output",
-            action="store", default=None,
-            help=_("Render the specified project to OUTPUT_FILE with no GUI."))
-    parser.add_option("-p", "--preview",
-            action="store_true", default=False,
-            help=_("Preview the specified project file without the full UI."))
     options, args = parser.parse_args(argv[1:])
 
     # Validate options.
-    if options.render_output and options.preview:
-        parser.error(_("-p and -r cannot be used simultaneously"))
-
-    if options.import_sources and (options.render_output or options.preview):
-        parser.error(_("-r or -p and -i are incompatible"))
-
     if options.add_to_timeline and not options.import_sources:
         parser.error(_("-a requires -i"))
 
@@ -481,12 +428,6 @@ def _parse_options(argv):
     if options.import_sources:
         # When no MEDIA_FILE is specified, we just create a new project.
         pass
-    elif options.render_output:
-        if len(args) != 1:
-            parser.error(_("-r requires exactly one PROJECT_FILE"))
-    elif options.preview:
-        if len(args) != 1:
-            parser.error(_("-p requires exactly one PROJECT_FILE"))
     else:
         if len(args) > 1:
             parser.error(_("Cannot open more than one PROJECT_FILE"))
@@ -500,12 +441,6 @@ def main(argv):
         ptv = ProjectCreatorGuiPitivi(media_filenames=args,
                                       add_to_timeline=options.add_to_timeline,
                                       debug=options.debug)
-    elif options.render_output:
-        ptv = RenderingNoGuiPitivi(project_filename=args[0],
-                                   output_filename=options.render_output,
-                                   debug=options.debug)
-    elif options.preview:
-        ptv = PreviewGuiPitivi(project_filename=args[0], debug=options.debug)
     else:
         if args:
             ptv = ProjectLoaderGuiPitivi(project_filename=args[0],
