@@ -604,6 +604,7 @@ class Project(Loggable, GES.Project):
         self._vcodecsettings_cache = {}
         # A (aencoder -> acodecsettings) map.
         self._acodecsettings_cache = {}
+        self._has_rendering_values = False
 
     #-----------------#
     # Our properties  #
@@ -647,15 +648,44 @@ class Project(Loggable, GES.Project):
         self.setModificationState(True)
 
     # Encoding related properties
+    def set_rendering(self, rendering):
+        if rendering and self._has_rendering_values != rendering:
+            self.videowidth = self.videowidth * self.render_scale / 100
+            self.videoheight = self.videoheight * self.render_scale / 100
+        elif self._has_rendering_values != rendering:
+            self.videowidth = self.videowidth / self.render_scale * 100
+            self.videoheight = self.videoheight / self.render_scale * 100
+        else:
+            restriction = self.video_profile.get_restriction().copy_nth(0)
+            self.video_profile.set_restriction(restriction)
+
+            restriction = self.audio_profile.get_restriction().copy_nth(0)
+            self.audio_profile.set_restriction(restriction)
+        self._has_rendering_values = rendering
+
+    def set_video_restriction_value(self, name, value):
+        if self.video_profile.get_restriction()[0][name] != value and value:
+            restriction = self.video_profile.get_restriction().copy_nth(0)
+            restriction[0][name] = value
+            self.video_profile.set_restriction(restriction)
+            return True
+        return False
+
+    def set_audio_restriction_value(self, name, value):
+        if self.audio_profile.get_restriction()[0][name] != value and value:
+            restriction = self.audio_profile.get_restriction().copy_nth(0)
+            restriction[0][name] = value
+            self.audio_profile.set_restriction(restriction)
+            return True
+        return False
+
     @property
     def videowidth(self):
         return self.video_profile.get_restriction()[0]["width"]
 
     @videowidth.setter
     def videowidth(self, value):
-        value = int(value)
-        if self.video_profile.get_restriction()[0]["width"] != value and value:
-            self.video_profile.get_restriction()[0]["width"] = value
+        if self.set_video_restriction_value("width", int(value)):
             self._emitChange("rendering-settings-changed", "width", value)
 
     @property
@@ -665,8 +695,7 @@ class Project(Loggable, GES.Project):
     @videoheight.setter
     def videoheight(self, value):
         value = int(value)
-        if self.video_profile.get_restriction()[0]["height"] != value and value:
-            self.video_profile.get_restriction()[0]["height"] = value
+        if self.set_video_restriction_value("height", int(value)):
             self._emitChange("rendering-settings-changed", "height", value)
 
     @property
@@ -675,8 +704,7 @@ class Project(Loggable, GES.Project):
 
     @videorate.setter
     def videorate(self, value):
-        if self.video_profile.get_restriction()[0]["framerate"] != value and value:
-            self.video_profile.get_restriction()[0]["framerate"] = value
+        if self.set_video_restriction_value("framerate", value):
             self._emitChange("rendering-settings-changed", "videorate", value)
 
     @property
@@ -685,8 +713,7 @@ class Project(Loggable, GES.Project):
 
     @videopar.setter
     def videopar(self, value):
-        if self.video_profile.get_restriction()[0]["pixel-aspect-ratio"] != value and value:
-            self.video_profile.get_restriction()[0]["pixel-aspect-ratio"] = value
+        self.set_video_restriction_value("pixel-aspect-ratio", value)
 
     @property
     def audiochannels(self):
@@ -694,8 +721,7 @@ class Project(Loggable, GES.Project):
 
     @audiochannels.setter
     def audiochannels(self, value):
-        if self.audio_profile.get_restriction()[0]["channels"] != value and value:
-            self.audio_profile.get_restriction()[0]["channels"] = value
+        if self.set_audio_restriction_value("channels", value):
             self._emitChange("rendering-settings-changed", "channels", value)
 
     @property
@@ -707,9 +733,7 @@ class Project(Loggable, GES.Project):
 
     @audiorate.setter
     def audiorate(self, value):
-        if self.audio_profile.get_restriction()[0]["rate"] != value and \
-                value is not None:
-            self.audio_profile.get_restriction()[0]["rate"] = int(value)
+        if self.set_audio_restriction_value("rate", value):
             self._emitChange("rendering-settings-changed", "rate", value)
 
     @property
@@ -848,6 +872,8 @@ class Project(Loggable, GES.Project):
         self.timeline = self.extract()
         if self.timeline is None:
             return False
+        if not self.timeline.get_layers():
+            self.timeline.props.auto_transition = True
         self._calculateNbLoadingAssets()
 
         self.timeline.selection = Selection()
@@ -903,10 +929,17 @@ class Project(Loggable, GES.Project):
         @type render: bool
         """
         if render:
-            scale = self.render_scale
-        else:
-            scale = 100
-        return self.videowidth * scale / 100, self.videoheight * scale / 100
+            if not self._has_rendering_values:
+                return (self.videowidth * self.render_scale / 100,
+                        self.videoheight * self.render_scale / 100)
+            else:
+                return self.videowidth, self.videoheight
+
+        if self._has_rendering_values:
+            return (self.videowidth / self.render_scale * 100,
+                    self.videoheight / self.render_scale * 100)
+
+        return self.videowidth, self.videoheight
 
     def getVideoCaps(self, render=False):
         """ Returns the GstCaps corresponding to the video settings """
