@@ -313,6 +313,8 @@ class RenderDialog(Loggable):
     """
     INHIBIT_REASON = _("Currently rendering")
 
+    _factory_formats = {}
+
     def __init__(self, app, project, pipeline=None):
 
         from pitivi.preset import RenderPresetManager
@@ -834,6 +836,7 @@ class RenderDialog(Loggable):
     def _shutDown(self):
         """ The render process has been aborted, shutdown the gstreamer pipeline
         and disconnect from its signals """
+        self.project.set_rendering(False)
         self._is_rendering = False
         self._rendering_is_paused = False
         self._time_spent_paused = 0
@@ -886,17 +889,24 @@ class RenderDialog(Loggable):
         self.progress = RenderingProgressDialog(self.app, self)
         self.window.hide()  # Hide the rendering settings dialog while rendering
 
-        # Now find a format to set on the restriction caps.
-        # The reason is we can't send different formats on the encoders.
-        factory = Gst.ElementFactory.find(self.project.vencoder)
-        for struct in factory.get_static_pad_templates():
-            if struct.direction == Gst.PadDirection.SINK:
-                caps = struct.get_caps()
-                fixed = caps.fixate()
-                fmt = fixed.get_structure(0).get_value("format")
-                self.project.video_profile.get_restriction()[0]["format"] = fmt
-                break
+        encoder_string = self.project.vencoder
+        try:
+            fmt = self._factory_formats[encoder_string]
+            self.project.video_profile.get_restriction()[0]["format"] = fmt
+        except KeyError:
+            # Now find a format to set on the restriction caps.
+            # The reason is we can't send different formats on the encoders.
+            factory = Gst.ElementFactory.find(self.project.vencoder)
+            for struct in factory.get_static_pad_templates():
+                if struct.direction == Gst.PadDirection.SINK:
+                    caps = Gst.Caps.from_string(struct.get_caps().to_string())
+                    fixed = caps.fixate()
+                    fmt = fixed.get_structure(0).get_value("format")
+                    self.project.video_profile.get_restriction()[0]["format"] = fmt
+                    self._factory_formats[encoder_string] = fmt
+                    break
 
+        self.project.set_rendering(True)
         self._pipeline.set_render_settings(self.outfile, self.project.container_profile)
         self.startAction()
         self.progress.window.show()
@@ -1040,7 +1050,7 @@ class RenderDialog(Loggable):
         self.updateResolution()
 
     def updateResolution(self):
-        width, height = self.project.getVideoWidthAndHeight(render=True)
+        width, height = self.project.getVideoWidthAndHeight(True)
         self.resolution_label.set_text(u"%d×%d" % (width, height))
 
     def _projectSettingsButtonClickedCb(self, button):
