@@ -577,6 +577,10 @@ class TimelineElement(Clutter.Actor, Zoomable):
         adj = self.nsToPixel(keyframe.value.timestamp - lastKeyframe.value.timestamp)
         opp = (lastKeyframe.value.value - keyframe.value.value) * EXPANDED_SIZE
         hyp = math.sqrt(adj ** 2 + opp ** 2)
+
+        if (hyp < 1):  # line length would be less tan one pixel
+            return
+
         sinX = opp / hyp
         line.props.width = hyp
         line.props.height = KEYFRAME_SIZE
@@ -767,6 +771,7 @@ class Line(Clutter.Actor):
 
     def transposeXY(self, x, y):
         x -= self.timelineElement.props.x + CONTROL_WIDTH - self.timelineElement.timeline._scroll_point.x
+        x += Zoomable.nsToPixel(self.timelineElement.bElement.props.in_point)
         y -= self.timelineElement.props.y
         return x, y
 
@@ -946,7 +951,7 @@ class Keyframe(Clutter.Actor):
         newValue = self.valueStart - (delta_y / EXPANDED_SIZE)
 
         # Don't overlap first and last keyframes.
-        newTs = min(max(newTs, self.inpoint + 1), self.duration - 1)
+        newTs = min(max(newTs, self.inpoint + 1), self.duration + self.inpoint - 1)
 
         newValue = min(max(newValue, 0.0), 1.0)
 
@@ -1029,12 +1034,6 @@ class URISourceElement(TimelineElement):
         self.background.set_position(0, 0)
 
     # Callbacks
-    def _selectedChangedCb(self, selected, isSelected):
-        TimelineElement._selectedChangedCb(self, selected, isSelected)
-
-        if isSelected:
-            self.timeline._container.app.gui.switchContextTab("clip configuration")
-
     def _clickedCb(self, action, actor):
         #TODO : Let's be more specific, masks etc ..
         children = self.bElement.get_toplevel_parent().get_children(True)
