@@ -31,16 +31,16 @@ import os
 import pickle
 import resource
 import sqlite3
-import xdg.BaseDirectory as xdg_dirs
 
 # Our C module optimizing waveforms rendering
 import renderer
 
+from pitivi.settings import get_dir, xdg_cache_home
 from pitivi.utils.signal import Signallable
 from pitivi.utils.loggable import Loggable
 from pitivi.utils.timeline import Zoomable
 from pitivi.utils.ui import EXPANDED_SIZE
-from pitivi.utils.misc import filename_from_uri, quote_uri
+from pitivi.utils.misc import filename_from_uri, quote_uri, hash_file
 from pitivi.utils.ui import CONTROL_WIDTH
 
 
@@ -513,6 +513,7 @@ class VideoPreviewer(Clutter.ScrollActor, PreviewGenerator, Zoomable, Loggable):
         PreviewGenerator.emit(self, "done")
 
     def cleanup(self):
+        self.stopGeneration()
         Zoomable.__del__(self)
 
 
@@ -546,29 +547,6 @@ class Thumbnail(Clutter.Actor):
         self.restore_easing_state()
 
 
-# TODO: replace with utils.misc.hash_file
-def hash_file(uri):
-    """Hashes the first 256KB of the specified file"""
-    sha256 = hashlib.sha256()
-    with open(uri, "rb") as file:
-        for _ in range(1024):
-            chunk = file.read(256)
-            if not chunk:
-                break
-            sha256.update(chunk)
-    return sha256.hexdigest()
-
-# TODO: remove eventually
-autocreate = True
-
-
-# TODO: replace with pitivi.settings.get_dir
-def get_dir(path, autocreate=True):
-    if autocreate and not os.path.exists(path):
-        os.makedirs(path)
-    return path
-
-
 caches = {}
 
 
@@ -590,12 +568,10 @@ class ThumbnailCache(Loggable):
 
     def __init__(self, uri):
         Loggable.__init__(self)
-        # TODO: replace with utils.misc.hash_file
         self._filehash = hash_file(Gst.uri_get_location(uri))
         self._filename = filename_from_uri(uri)
-        # TODO: replace with pitivi.settings.xdg_cache_home()
-        cache_dir = get_dir(os.path.join(xdg_dirs.xdg_cache_home, "pitivi"), autocreate)
-        dbfile = os.path.join(get_dir(os.path.join(cache_dir, "thumbs")), self._filehash)
+        thumbs_cache_dir = get_dir(os.path.join(xdg_cache_home(), "thumbs"))
+        dbfile = os.path.join(thumbs_cache_dir, self._filehash)
         self._db = sqlite3.connect(dbfile)
         self._cur = self._db.cursor()  # Use this for normal db operations
         self._cur.execute("CREATE TABLE IF NOT EXISTS Thumbs\
@@ -777,7 +753,7 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
     def _startLevelsDiscovery(self):
         self.log('Preparing waveforms for "%s"' % filename_from_uri(self._uri))
         filename = hash_file(Gst.uri_get_location(self._uri)) + ".wave"
-        cache_dir = get_dir(os.path.join(xdg_dirs.xdg_cache_home, os.path.join("pitivi/waves")), autocreate)
+        cache_dir = get_dir(os.path.join(xdg_cache_home(), "waves"))
         filename = cache_dir + "/" + filename
 
         if os.path.exists(filename):
@@ -988,6 +964,7 @@ class AudioPreviewer(Clutter.Actor, PreviewGenerator, Zoomable, Loggable):
         PreviewGenerator.emit(self, "done")
 
     def cleanup(self):
+        self.stopGeneration()
         self.canvas.disconnect_by_func(self._drawContentCb)
         self.timeline.disconnect_by_func(self._scrolledCb)
         Zoomable.__del__(self)
