@@ -15,17 +15,17 @@ class BasicTest(TestCase):
         self.assert_(ptv)
 
         # were the contents of pitivi properly created
-        self.assertEqual(ptv.current, None)
+        self.assertEqual(ptv.current_project, None)
         self.assert_(ptv.effects)
 
         # was the unique instance object properly set
-        self.assertEquals(pitivi.instance.PiTiVi, ptv)
+        self.assertEquals(pitivi.instance.Pitivi, ptv)
 
         # close pitivi
         ptv.shutdown()
 
         # make sure the instance has been unset
-        self.assertEquals(pitivi.instance.PiTiVi, None)
+        self.assertEquals(pitivi.instance.Pitivi, None)
 
 if __name__ == "__main__":
     unittest.main()
